import { PluginConfig } from '../../types';
import { ViteDevServer } from 'vite';
/**
 * Service to coordinate file caching, directory watching, and module invalidation.
 * Provides methods to manage file caching and handle file changes in Vite server.
 */
export declare class CacheService {
    private fileCache;
    private fileWatcher;
    private moduleInvalidator;
    /**
     * Creates an instance of CacheService with a specified cache size.
     *
     * @param {number} [maxCacheSize=100] - The maximum number of files to cache. Defaults to 100.
     */
    constructor(maxCacheSize?: number);
    /**
     * Updates the cache for specified directories and invalidates Vite modules.
     * It handles HTML and templ file caching and triggers module reloading in Vite.
     *
     * @param {any} server - The Vite server instance.
     * @param {string} serverRoot - The root directory of the server.
     * @param {PluginConfig} finalOptions - The plugin configuration options.
     * @param {boolean} [isFirstServerRun=true] - Indicates if this is the first run of the server. Defaults to true.
     * @returns {Promise<void>} - A promise that resolves when the cache is updated and modules are invalidated.
     */
    updateCacheAndInvalidate(server: any, serverRoot: string, finalOptions: PluginConfig, isFirstServerRun?: boolean): Promise<void>;
    /**
     * Adds a file to be watched for changes and associates it with an ID.
     *
     * @param {string} filePath - The path of the file to watch.
     * @param {string} id - The identifier associated with the file.
     */
    watchFileChanges(filePath: string, id: string): void;
    /**
     * Handles a file change event with an optional delay before sending reload events.
     * @param server - Vite's Dev Server instance.
     * @param file - The file path that triggered the change.
     * @param delay - Delay in milliseconds before handling the file change.
     */
    handleFileChange(server: ViteDevServer, file: string, delay?: number): void;
    /**
     * Clears the entire file cache.
     */
    clearCache(): void;
    /**
     * Retrieves the cached content of a file or returns default content if the file is not cached.
     *
     * @param {string} filePath - The path of the file to retrieve from the cache.
     * @param {string} defaultContent - The content to return if the file is not found in the cache.
     * @returns {string} - The cached content or the default content.
     */
    getCachedContent(filePath: string, defaultContent: string): string;
    /**
     * Saves the current state of the cache to a file on disk.
     *
     * @param {string} filePath - The path where the cache should be saved.
     * @returns {Promise<void>} - A promise that resolves when the cache is saved.
     */
    saveCacheToFile(filePath: string): Promise<void>;
    /**
     * Loads a previously saved cache from a file on disk and populates the in-memory cache.
     *
     * @param {string} filePath - The path of the file from which to load the cache.
     * @returns {Promise<void>} - A promise that resolves when the cache is loaded.
     */
    loadCacheFromFile(filePath: string): Promise<void>;
}
