/**
 * Manage in-memory caching of file content with size limits and persistence features.
 */
export declare class FileCache {
    private cache;
    private maxCacheSize;
    /**
     * Creates an instance of FileCache.
     *
     * @param {number} maxCacheSize - The maximum number of files to cache. Defaults to 100.
     */
    constructor(maxCacheSize?: number);
    /**
     * Updates the cache with the content of a specific file.
     *
     * @param {string} filePath - The path of the file to cache.
     * @param {string} content - The content to store in the cache.
     */
    updateCacheForFile(filePath: string, content: string): Promise<void>;
    /**
     * Retrieves the cached content for a given file, or returns default content if the file is not cached.
     *
     * @param {string} filePath - The path of the file to retrieve from the cache.
     * @param {string} defaultContent - The content to return if the file is not found in the cache.
     * @returns {string} - The cached content or the default content.
     */
    getCacheContent(filePath: string, defaultContent: string): string;
    /**
     * Ensures the cache size does not exceed the specified maximum by removing the oldest entries.
     */
    private checkCacheSize;
    /**
     * Clears all files from the cache.
     */
    clearCache(): void;
    /**
     * Saves the current cache to a file on disk.
     *
     * @param {string} filePath - The path to save the cache file.
     * @returns {Promise<void>} - A promise that resolves when the cache is saved.
     */
    saveCacheToFile(filePath: string): Promise<void>;
    /**
     * Loads a cache from a file on disk and populates the in-memory cache.
     *
     * @param {string} filePath - The path of the cache file to load.
     * @returns {Promise<void>} - A promise that resolves when the cache is loaded.
     */
    loadCacheFromFile(filePath: string): Promise<void>;
}
