import { Token } from './css-tokenizer';
/**
 * A utility class for converting CSS tokens back into a CSS string.
 * Supports pretty-printing and minification.
 */
export declare class CssStringifier {
    /**
     * Converts tokens back into a CSS string.
     *
     * @param {Token[]} tokens - The tokens to stringify.
     * @param {boolean} [minify=false] - Whether to minify the output CSS.
     * @returns {string} - The reconstructed CSS string.
     */
    static serializeTokens(tokens: Token[], minify?: boolean): string;
    /**
     * Pretty-prints the CSS string from tokens.
     *
     * @param {Token[]} tokens - The tokens to stringify.
     * @returns {string} - The pretty-printed CSS string.
     */
    static prettyPrint(tokens: Token[]): string;
    /**
     * Minifies the CSS string from tokens.
     *
     * @param {Token[]} tokens - The tokens to stringify.
     * @returns {string} - The minified CSS string.
     */
    static minify(tokens: Token[]): string;
    /**
     * Logs tokens for debugging purposes.
     *
     * @param {Token[]} tokens - The tokens to debug.
     */
    static log(tokens: Token[]): void;
    /**
     * Processes an individual token and returns its serialized string.
     *
     * @param {Token} token - The token to process.
     * @param {boolean} minify - Whether to minify the output CSS.
     * @param {number} indentationLevel - The current indentation level.
     * @returns {string} - The serialized string for the token.
     */
    private static processToken;
    /**
     * Serializes a rule token.
     *
     * @param {Token} token - The rule token to serialize.
     * @param {boolean} minify - Whether to minify the output CSS.
     * @param {number} indentationLevel - The current indentation level.
     * @returns {string} - The serialized rule string.
     */
    private static serializeRule;
    /**
     * Serializes a declaration token.
     *
     * @param {Token} token - The declaration token to serialize.
     * @param {boolean} minify - Whether to minify the output CSS.
     * @param {number} indentationLevel - The current indentation level.
     * @returns {string} - The serialized declaration string.
     */
    private static serializeDeclaration;
    /**
     * Serializes an at-rule token.
     *
     * @param {Token} token - The at-rule token to serialize.
     * @param {boolean} minify - Whether to minify the output CSS.
     * @param {number} indentationLevel - The current indentation level.
     * @returns {string} - The serialized at-rule string.
     */
    private static serializeAtRule;
}
