import { CssSerializer } from './css-serializer';
import { Token } from './css-tokenizer';
import { TokenProcessorStrategy, TokenProcessorStrategyOptions } from './strategies/token-processor-strategy';
/**
 * Default options for the Token Processor Strategy.
 */
export declare const DEFAULT_TOKEN_PROCESSOR_OPTIONS: Required<TokenProcessorStrategyOptions>;
/**
 * Class for processing CSS tokens using a given strategy.
 */
export declare class CssTokenProcessor implements CssSerializer {
    private strategies;
    private options;
    /**
     * Creates an instance of CssTokenProcessor.
     *
     * @param {TokenProcessorStrategy[]} strategies - The initial strategy to use for processing.
     * @param {TokenProcessorStrategyOptions} [options] - Default options for processing.
     */
    constructor(strategies?: TokenProcessorStrategy[], options?: TokenProcessorStrategyOptions);
    /**
     * Adds a new strategy for processing CSS tokens.
     *
     * @param {TokenProcessorStrategy} strategy - The strategy to add.
     */
    addStrategy(strategy: TokenProcessorStrategy): void;
    /**
     * Sets the options for processing CSS tokens.
     *
     * @param {TokenProcessorStrategyOptions} options - The options to set.
     */
    setOptions(options: TokenProcessorStrategyOptions): void;
    /**
     * Executes the current strategy on a given set of tokens.
     *
     * @param {Token[]} tokens - The tokens to process.
     * @param {TokenProcessorStrategyOptions} [options] - Additional options for the strategy.
     * @returns {Token[]} - The processed tokens.
     */
    execute(tokens: Token[], options?: TokenProcessorStrategyOptions): Token[];
    /**
     * Builds the formatted or minified CSS string from the filtered tokens.
     *
     * @param {Token[]} tokens - The tokens to convert to CSS.
     * @param {TokenProcessorStrategyOptions} [options] - Additional options for building the CSS.
     * @returns {string} - The constructed CSS string.
     */
    serialize(tokens: Token[], options?: TokenProcessorStrategyOptions): string;
    /**
     * Builds the formatted CSS string from the filtered tokens.
     *
     * @param {Token[]} tokens - The tokens to convert to CSS.
     * @returns {string} - The constructed CSS string.
     */
    prettyPrint(tokens: Token[]): string;
    /**
     * Builds the minified CSS string from the filtered tokens.
     *
     * @param {Token[]} tokens - The tokens to convert to CSS.
     * @returns {string} - The constructed CSS string.
     */
    minify(tokens: Token[]): string;
    /**
     * Merges provided options with defaults.
     *
     * @param {TokenProcessorStrategyOptions} [options] - Options to merge with defaults.
     * @returns {Required<TokenProcessorStrategyOptions>} - The merged options.
     */
    private mergeOptions;
}
