/**
 * Type for specific keys used in token details.
 */
type DetailsKeys = 'property' | 'value' | 'name';
/**
 * Type for token details, supporting specific and additional contextual keys.
 */
type Details = {
    [K in DetailsKeys]?: string;
} & Record<Exclude<string, DetailsKeys>, string>;
/**
 * Represents a token generated during the CSS parsing process.
 */
export type Token = {
    /** The type of token ('rule', 'at-rule', or 'declaration'). */
    type: 'rule' | 'at-rule' | 'declaration';
    /** The serialized value of the token. */
    value: string;
    /** Additional contextual details about the token. */
    details: Details;
    /** Nested tokens for hierarchical structures. */
    children: Token[];
};
/**
 * Tokenizer class for parsing CSS into structured tokens using csstree.
 */
export declare class CssTokenizer {
    /** Internal list of tokens generated during parsing. */
    private tokens;
    /**
     * Parses a CSS string and generates a list of tokens.
     *
     * @param {string} css - The CSS string to tokenize.
     * @returns {Token[]} - The list of generated tokens.
     */
    tokenize(css: string): Token[];
    /**
     * Processes an at-rule node and generates a corresponding token.
     *
     * @param {csstree.Atrule} node - The at-rule node to process.
     * @param {Token | null} parentToken - The parent token, if any.
     * @param {Token[]} parentStack - The stack of parent tokens.
     */
    private handleAtRule;
    /**
     * Processes a rule node and generates a corresponding token.
     *
     * @param {csstree.Rule} node - The rule node to process.
     * @param {Token | null} parentToken - The parent token, if any.
     * @param {Token[]} parentStack - The stack of parent tokens.
     */
    private handleRule;
    /**
     * Processes a declaration node and generates a corresponding token.
     *
     * @param {csstree.Declaration} node - The declaration node to process.
     * @param {Token | null} parentToken - The parent token, if any.
     */
    private handleDeclaration;
    /**
     * Adds a token to the appropriate parent or top-level collection.
     *
     * @param {Token} token - The token to add.
     * @param {Token | null} parentToken - The parent token, if any.
     * @param {Token[]} parentStack - The stack of parent tokens.
     */
    private addTokenToParent;
    /**
     * Pushes a token onto the parent stack if applicable.
     *
     * @param {Token} token - The token to push.
     * @param {Token[]} parentStack - The stack of parent tokens.
     */
    private pushToStackIfNeeded;
    /**
     * Removes a token from the stack if it is an at-rule or rule.
     *
     * @param {csstree.CssNode} node - The current AST node.
     * @param {Token[]} parentStack - The stack of parent tokens.
     */
    private popFromStackIfNeeded;
    /**
     * Creates a token for an at-rule node.
     *
     * @param {csstree.Atrule} node - The at-rule node.
     * @returns {Token} - The generated token.
     */
    private createAtRuleToken;
    /**
     * Creates a token for a rule node.
     *
     * @param {csstree.Rule} node - The rule node.
     * @returns {Token} - The generated token.
     */
    private createRuleToken;
    /**
     * Creates a token for a declaration node.
     *
     * @param {csstree.Declaration} node - The declaration node.
     * @returns {Token} - The generated token.
     */
    private createDeclarationToken;
    /**
     * Creates a token with the given type and details.
     *
     * @param {'rule' | 'at-rule' | 'declaration'} type - The token type.
     * @param {string} value - The serialized value of the token.
     * @param {Details} details - The token details.
     * @returns {Token} - The created token.
     */
    private createToken;
}
export {};
