import { HtmlTagOptimizer } from './optimizer';
/**
 * Class to optimize HTML scripts by deduplicating and consolidating script tags.
 */
declare class HtmlScriptsOptimizer implements HtmlTagOptimizer {
    private static instance;
    /** Message inserted for consolidated scripts in the first file. */
    private static readonly CONSOLIDATED_SCRIPTS_MSG;
    /** Message inserted for files where duplicated scripts were removed. */
    private static readonly DUPLICATED_SCRIPTS_FOUND_MSG;
    /** Regex to match <script> tags in HTML. */
    private static readonly SCRIPT_TAG_REGEX;
    /** Directory containing HTML files to optimize. */
    private inputDirectory;
    /**
     * Private constructor to prevent direct class instantiation.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     */
    private constructor();
    /**
     * Returns the singleton instance of HtmlScriptsOptimizer.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     * @returns {HtmlScriptsOptimizer} - The singleton instance.
     */
    static getInstance(inputDirectory: string): HtmlScriptsOptimizer;
    /**
     * Main function to optimize scripts by deduplicating and consolidating script tags across multiple HTML files.
     */
    run(): void;
    /**
     * Collects all script tags and file contents from the specified HTML files.
     * @param {string[]} htmlFiles - Array of HTML file paths to process.
     * @returns {object} - An object containing all script tags and file contents.
     */
    private collectScriptsFromFiles;
    /**
     * Processes the HTML files to remove and consolidate script tags.
     * @param {string[]} htmlFiles - Array of HTML file paths to process.
     * @param {Map<string, string>} fileContents - Mapping of file paths to their HTML contents.
     * @param {Set<string>} allScriptTags - Set of all script tag contents across files.
     */
    private processFiles;
    /**
     * Extracts script tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to extract script tags from.
     * @returns {string[]} - An array of script tag contents.
     */
    private extractScriptTags;
    /**
     * Removes all script tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to process.
     * @returns {string} - The HTML content without script tags.
     */
    private removeScriptTags;
    /**
     * Inserts all consolidated script tags into the specified HTML file.
     * @param {string} filePath - The path to the HTML file.
     * @param {string[]} scriptTags - Array of script tag contents to insert.
     */
    private insertAllScriptTags;
    /**
     * Recursively reads all directories from the specified directory.
     * @param {string} dir - The directory to read subdirectories from.
     * @returns {string[]} - An array of directory paths.
     */
    private readDirectoriesRecursive;
    /**
     * Reads all HTML files from the specified directory.
     * @param {string} dir - The directory to read HTML files from.
     * @returns {string[]} - An array of HTML file paths.
     */
    private readHtmlFiles;
}
export default HtmlScriptsOptimizer;
