import { TokenProcessorStrategyOptions } from '../css-processor/strategies/token-processor-strategy';
import { HtmlTagOptimizer } from './optimizer';
/**
 * Class to optimize HTML styles by deduplicating and consolidating styles tags.
 */
declare class HtmlStylesOptimizer implements HtmlTagOptimizer {
    /** Singleton instance of the HtmlStylesOptimizer class.*/
    private static instance;
    /** Message inserted for consolidated styles in the first file. */
    private static readonly CONSOLIDATED_STYLES_MSG;
    /** Message inserted for files where duplicated styles were removed. */
    private static readonly DUPLICATED_STYLES_FOUND_MSG;
    /** Regex to match <style> tags in HTML. */
    private static readonly STYLE_TAG_REGEX;
    /**
     * Default options for the Token Processor Strategy.
     */
    private static readonly DEFAULT_OPTIONS;
    /** Directory containing HTML files to optimize. */
    private inputDirectory;
    /** Instance of CssTokenProcessor to process and extract CSS layer contents. */
    private cssTokenProcessor;
    /** Instance of CssRulesAnalyzer to analyze and process CSS rules. */
    private cssRulesAnalyzer;
    /** Options for the Token Processor Strategy. */
    private options;
    /**
     * Private constructor to initialize with the input directory and options.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     * @param {TokenProcessorStrategyOptions} [options] - Options for the CSS processor.
     */
    private constructor();
    /**
     * Sets the options for the LayerProcessor.
     *
     * @param {TokenProcessorStrategyOptions} options - Options to update.
     */
    setOptions(options: TokenProcessorStrategyOptions): void;
    /**
     * Gets the singleton instance of HtmlStylesOptimizer.
     * @param {string} inputDirectory - The directory containing HTML files to optimize.
     * @param {TokenProcessorStrategyOptions} [options] - Options for the CSS processor.
     * @returns {HtmlStylesOptimizer} - The singleton instance.
     */
    static getInstance(inputDirectory: string, options?: TokenProcessorStrategyOptions): HtmlStylesOptimizer;
    /**
     * Updates the options for the optimizer.
     * @param {TokenProcessorStrategyOptions} options - New options to update.
     */
    updateOptions(options: TokenProcessorStrategyOptions): void;
    /**
     * Main entry point to optimize styles in all relevant HTML files.
     */
    run(): void;
    /**
     * Consolidates styles across HTML files.
     * @param {string[]} htmlFiles - Array of HTML file paths.
     * @returns {{
     *   consolidatedStyles: Map<string, string[]>;
     *   uniqueStyles: Map<string, string[]>;
     * }} - Consolidated and unique styles.
     */
    private consolidateStylesAcrossFiles;
    /**
     * Loads the content of HTML files.
     * @param {string[]} htmlFiles - Array of HTML file paths.
     * @returns {Map<string, string>} - Map of file paths to their content.
     */
    private loadFileContents;
    /**
     * Extracts and normalizes CSS blocks from HTML files.
     * @param {string[]} htmlFiles - Array of HTML file paths.
     * @param {Map<string, string>} fileContents - Map of file paths to their content.
     * @returns {{
     *   rawCssBlocksByFile: Map<string, Set<string>>;
     *   cssInputs: string[];
     *   ruleToFileMap: Map<string, string>;
     *   inputToFileMap: Map<string, string>;
     * }} - Data structures for CSS extraction and mapping.
     */
    private extractAndNormalizeCssBlocks;
    /**
     * Computes consolidated styles for duplicate rules.
     * @param {Map<string, { rule: string; sources: string[] }>} duplicates - Duplicate rules.
     * @param {Map<string, string>} ruleToFileMap - Mapping of rules to their first file.
     * @returns {Map<string, string[]>} - Map of file paths to consolidated styles.
     */
    private getConsolidatedStyles;
    /**
     * Computes unique styles for each file.
     * @param {string[]} htmlFiles - Array of HTML file paths.
     * @param {Map<string, Set<string>>} rawCssBlocksByFile - Map of file paths to raw CSS blocks.
     * @param {Map<string, { rule: string; sources: string[] }>} uniqueEntries - Unique rules.
     * @param {Map<string, string>} inputToFileMap - Mapping of input identifiers to file paths.
     * @returns {Map<string, string[]>} - Map of file paths to unique styles.
     */
    private getUniqueStyles;
    /**
     * Updates HTML files with consolidated and unique styles.
     * @param {string[]} htmlFiles - Array of HTML file paths.
     * @param {string[]} consolidatedStyles - Consolidated duplicate CSS rules.
     * @param {Map<string, string[]>} uniqueStyles - Map of unique styles for each file.
     */
    private updateHtmlFiles;
    /**
     * Extracts style tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to extract style tags from.
     * @returns {string[]} An array of style tag contents.
     */
    private extractStyleTags;
    /**
     * Wraps a list of styles into a <style> block.
     * @param {string[]} styles - List of serialized CSS rules.
     * @returns {string} - The resulting <style> block.
     */
    private wrapWithStyleTag;
    /**
     * Removes all <style> tags from the given HTML content.
     * @param {string} htmlContent - The HTML content to process.
     * @returns {string} - The HTML content without <style> tags.
     */
    private removeStyleTags;
    /**
     * Recursively reads all subdirectories from the specified directory.
     * @param {string} dir - The directory to read.
     * @returns {string[]} - Array of all directories including the root directory.
     */
    private readDirectoriesRecursive;
    /**
     * Reads all HTML files from the specified directory.
     * @param {string} dir - The directory to scan for HTML files.
     * @returns {string[]} - Array of file paths to HTML files.
     */
    private readHtmlFiles;
    /**
     * Merges provided options with defaults.
     *
     * @param {TokenProcessorStrategyOptions} [options] - Options to merge with defaults.
     * @returns {Required<TokenProcessorStrategyOptions>} - The merged options.
     */
    private mergeOptions;
}
export default HtmlStylesOptimizer;
